pub fn advance(
data: &Drawing<'_>,
block: BlockId,
current: EditTarget,
) -> Option<Transition>Expand description
Switch to editing the field after current in child block block’s cycle.
pub fn advance(
data: &Drawing<'_>,
block: BlockId,
current: EditTarget,
) -> Option<Transition>Switch to editing the field after current in child block block’s cycle.