tool_for_target

Function tool_for_target 

pub fn tool_for_target(data: &Drawing<'_>, target: EditTarget) -> Option<Tool>
Build the editor tool for target, or None when the field is not there or its interface is frozen.