delete_blocked_by_lock

Function delete_blocked_by_lock 

fn delete_blocked_by_lock(sel: &Deletable, data: &Drawing<'_>) -> bool
Whether the Delete/Cut controls are withheld because the selection is a locked pin/port interface: any selected child-block pin whose owner is locked, or a boundary port of a locked current block.