create

Function create 

fn create(
    data: &mut Drawing<'_>,
    start: Pos2,
    corner: Pos2,
) -> Option<Transition>
Add the block spanning the two corners and drop straight into naming it. None when the corners are too close to make a block — a block’s smallest valid height is 4 grid cells (one pin slot).