add_pin

Function add_pin 

pub(crate) fn add_pin(
    data: &mut Drawing<'_>,
    marker: SlotMarker,
) -> Option<Transition>
Add the pin marker offers and open its name for editing. None when the block declines it, as a block locked since the marker was drawn does.