draw_route_markers

Function draw_route_markers 

pub(crate) fn draw_route_markers<C: Canvas>(
    markers: &[SlotMarker],
    pointer: Pos2,
    painter: &mut Style<'_, C>,
) -> Option<SlotMarker>
Draw the route tool’s markers and return the one armed — grown to the full control — if any. A marker’s resting dot appears once the pointer is within NEW_PIN_ACTIVATION_RANGE; the nearest grows into the ring once the pointer is within NEW_PIN_GROW_RANGE.