pub fn markers_in_scope(data: &Drawing<'_>) -> Vec<SlotMarker>Expand description
The markers every block in the current scope offers.
pub fn markers_in_scope(data: &Drawing<'_>) -> Vec<SlotMarker>The markers every block in the current scope offers.