pub fn markers_on(data: &Drawing<'_>, block: BlockId) -> Vec<SlotMarker>Expand description
Every free slot’s marker on block, whether or not the block offers them.
pub fn markers_on(data: &Drawing<'_>, block: BlockId) -> Vec<SlotMarker>Every free slot’s marker on block, whether or not the block offers them.