fn grid_bounds(rect: ScreenRect) -> GridRectExpand description
Artwork is the document’s one unsnapped rect; the region that frames it is the whole cells it covers.
fn grid_bounds(rect: ScreenRect) -> GridRectArtwork is the document’s one unsnapped rect; the region that frames it is the whole cells it covers.