pub fn on_click(tool: ToolName, interaction: &Interaction) -> Option<Transition>Expand description
A click with tool armed, as the drop of tool where it landed.
pub fn on_click(tool: ToolName, interaction: &Interaction) -> Option<Transition>A click with tool armed, as the drop of tool where it landed.