pub fn displayed_tool(active: ToolName) -> ToolNameExpand description
The toolbar button that should show as selected while active is the current
tool. A base toolbar tool maps to itself; a sub-tool maps to the base tool it
originates from so exactly one toolbar button is always highlighted. Route
editing sub-tools are selection operations, so they (like every selection
microtool and any other non-toolbar tool) map to Select as the safe default.
The result is always a member of BAND_TOOLS.