pub(crate) fn draw_markers<C: Canvas>(
markers: &[SlotMarker],
interaction: &Interaction,
painter: &mut Style<'_, C>,
)Expand description
Draw markers as buttons: the one nearest the hover grows its ring, and
the one a press holds down is drawn inverted — a filled disk with a light
+ — and locks out the hover.