fn clamp_to_widest(
mode: ResizeMode,
orig: Rect,
widest: WorldPx,
delta: Vec2,
) -> Vec2Expand description
Clamp the x-component of a resize delta so the shape cannot grow wider than
widest, never forcing a shape already wider to shrink.